| orb_geo_points | R Documentation |
Places points on a map using the active projection. Use inside a plot that
also has an orb_map() layer, mapping x to longitude and y to latitude.
orb_geo_points(
...,
data = NULL,
size = 4,
colour = "#F76707",
alpha = 0.9,
stroke = 0.8
)
... |
Aesthetic mappings for this layer only, as |
data |
Optional data frame overriding the plot data. |
size |
Point radius in pixels when |
colour |
Fixed colour used when the |
alpha |
Opacity between 0 and 1. |
stroke |
Outline width in pixels. |
An object of class orb_layer.
cities <- data.frame(long = c(2.35, -74, 151.2), lat = c(48.86, 40.7, -33.87),
pop = c(11, 19, 5))
orb(cities, x = long, y = lat, size = pop) +
orb_map() + orb_points(colour = "#F76707") + orb_coord_map("robinson")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.