| orb_worldmap | R Documentation |
A convenience wrapper that returns a complete world map plot, optionally shaded by a value per region.
orb_worldmap(
values = NULL,
region_col = "region",
value_col = NULL,
projection = "equirectangular",
palette = "viridis",
ocean = NULL,
title = NULL
)
values, region_col, value_col |
Passed to |
projection |
Projection name; see |
palette |
Continuous palette name; see |
ocean |
Optional sea colour; see |
title |
Optional plot title. |
An orb_spec object.
orb_worldmap(projection = "orthographic")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.