plus-.orb_spec: Add layers, scales, labels and themes to a plot

+.orb_specR Documentation

Add layers, scales, labels and themes to a plot

Description

The + operator assembles a plot from parts, in the tradition of a layered grammar of graphics.

Usage

## S3 method for class 'orb_spec'
e1 + e2

Arguments

e1

An orb_spec object.

e2

A layer, scale, theme, labels or coordinate object to add.

Value

An orb_spec object.

Examples

orb(mtcars, x = wt, y = mpg) + orb_points() + orb_theme_dark()

orbis documentation built on Aug. 5, 2026, 9:08 a.m.