| orb_coord_cartesian | R Documentation |
The default coordinate system. Use it to return to Cartesian coordinates or to force a fixed aspect ratio.
orb_coord_cartesian(ratio = NULL)
ratio |
Data units per y unit relative to x, or |
An object of class orb_coord.
orb(mtcars, x = wt, y = mpg) + orb_points() + orb_coord_cartesian()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.