Skip to contents

A convenience wrapper that returns a complete world map plot, optionally shaded by a value per region.

Usage

orb_worldmap(
  values = NULL,
  region_col = "region",
  value_col = NULL,
  projection = "equirectangular",
  palette = "viridis",
  ocean = NULL,
  title = NULL
)

Arguments

values, region_col, value_col

Passed to orb_map() to build a choropleth.

projection

Projection name; see orb_coord_map().

palette

Continuous palette name; see orb_palettes().

ocean

Optional sea colour; see orb_map().

title

Optional plot title.

Value

An orb_spec object.

Examples

orb_worldmap(projection = "orthographic")
#> <orb_spec>
#>   data:   26953 rows x 4 columns
#>   mapping:  
#>   layers:  map