| +.orb_spec | R Documentation |
The + operator assembles a plot from parts, in the tradition of a layered
grammar of graphics.
## S3 method for class 'orb_spec'
e1 + e2
e1 |
An |
e2 |
A layer, scale, theme, labels or coordinate object to add. |
An orb_spec object.
orb(mtcars, x = wt, y = mpg) + orb_points() + orb_theme_dark()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.