worldclim_random() returns a random selection of parameters for
downloading WorldClim data.
Arguments
- series
A string indicating the WorldClim data series to use. The following options are available:
'hcd'(Historical Climate Data).'hmwd'(Historical Monthly Weather Data).'fcd'(Future Climate Data).
Value
A list with a random selection of parameters for
downloading WorldClim data. The list contains the following elements:
series: The selected data series.resolution: The selected spatial resolution.variable: The selected climate variable.bioclimatic_variable: The selected bioclimatic variable (only for Historical Climate Data and Future Climate Data whenvariableis set to"bioc").model: The selected climate model (only for Future Climate Data).ssp: The selected Shared Socioeconomic Pathway (only for Future Climate Data).year: The selected year or year range.month: The selected month.
See also
Other WorldClim functions:
worldclim_download(),
worldclim_extract_variable(),
worldclim_file(),
worldclim_to_ascii(),
worldclim_url()
Examples
worldclim_random("hcd")
#> $series
#> Historical Climate Data
#> "hcd"
#>
#> $resolution
#> 2.5 Minutes (~21 km2 at the Equator)
#> "2.5m"
#>
#> $variable
#> Average Temperature (°C)
#> "tavg"
#>
#> $year
#> 1970-2000
#> 1986
#>
#> $month
#> June
#> 6
#>
worldclim_random("hmwd")
#> $series
#> Historical Monthly Weather Data
#> "hmwd"
#>
#> $resolution
#> 5 Minutes (~85 km2 at the Equator)
#> "5m"
#>
#> $variable
#> Total Precipitation (mm)
#> "prec"
#>
#> $year
#> 1960-1969
#> 1962
#>
#> $month
#> September
#> 9
#>
worldclim_random("fcd")
#> $series
#> Future Climate Data
#> "fcd"
#>
#> $resolution
#> 5 Minutes (~85 km2 at the Equator)
#> "5m"
#>
#> $variable
#> Average Minimum Temperature (°C)
#> "tmin"
#>
#> $model
#> Australian Community Climate and Earth-System Simulator, Australia
#> "ACCESS-CM2"
#>
#> $ssp
#> SSP-126
#> "ssp126"
#>
#> $year
#> 2081-2100
#> 2089
#>
#> $month
#> June
#> 6
#>