Skip to contents

worldclim_random() returns a random selection of parameters for downloading WorldClim data.

Usage

worldclim_random(series = "hcd")

Arguments

series

A string indicating the WorldClim data series to use. The following options are available:

  • 'hcd' (Historical Climate Data).

  • 'hmwd' (Historical Monthly Weather Data).

  • 'fcd' (Future Climate Data).

Value

A list with a random selection of parameters for downloading WorldClim data. The list contains the following elements:

  • series: The selected data series.

  • resolution: The selected spatial resolution.

  • variable: The selected climate variable.

  • bioclimatic_variable: The selected bioclimatic variable (only for Historical Climate Data and Future Climate Data when variable is set to "bioc").

  • model: The selected climate model (only for Future Climate Data).

  • ssp: The selected Shared Socioeconomic Pathway (only for Future Climate Data).

  • year: The selected year or year range.

  • month: The selected month.

Examples

worldclim_random("hcd")
#> $series
#> Historical Climate Data 
#>                   "hcd" 
#> 
#> $resolution
#> 5 Minutes (~85 km2 at the Equator) 
#>                               "5m" 
#> 
#> $variable
#> Average Temperature (°C) 
#>                   "tavg" 
#> 
#> $year
#> 1970-2000 
#>      1996 
#> 
#> $month
#> August 
#>      8 
#> 

worldclim_random("hmwd")
#> $series
#> Historical Monthly Weather Data 
#>                          "hmwd" 
#> 
#> $resolution
#> 5 Minutes (~85 km2 at the Equator) 
#>                               "5m" 
#> 
#> $variable
#> Average Maximum Temperature (°C) 
#>                           "tmax" 
#> 
#> $year
#> 1950-1959 
#>      1952 
#> 
#> $month
#> August 
#>      8 
#> 

worldclim_random("fcd")
#> $series
#> Future Climate Data 
#>               "fcd" 
#> 
#> $resolution
#> 30 Seconds (~1 km2  at the Equator) 
#>                               "30s" 
#> 
#> $variable
#> Bioclimatic Variables 
#>                "bioc" 
#> 
#> $bioclimatic_variable
#> BIO1 - Annual Mean Temperature 
#>                              1 
#> 
#> $model
#> First Institute of Oceanography Earth System Model, China 
#>                                             "FIO-ESM-2-0" 
#> 
#> $ssp
#>  SSP-585 
#> "ssp585" 
#> 
#> $year
#> 2081-2100 
#>      2088 
#> 
#> $month
#> February 
#>        2 
#>